==> pdfadd_2.0.orig.tar.gz: pdfadd-2.0/tabvardialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2014 by Pascal Brachet                     *
 *   http://www.xm1math.net/pdfadd/                                        *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TABVARDIALOG_H
#define TABVARDIALOG_H

#include "ui_tabvardialog.h"
#include "latexhighlighter.h"
#include "pdfviewer.h"

#include <QProcess>
#include <QPointer>
#include <QCloseEvent>
#include <QProgressDialog>

class TabvarDialog : public QDialog  {
   Q_OBJECT
public:
	TabvarDialog(QWidget *parent=0);
	~TabvarDialog();
	Ui::TabvarDialog ui;
QString pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier;
private :
QString tempDir,texTempFile,pdfTempFile,prefixFile;
QPointer<QProcess> pdflatexproc;
bool estModifie, erreurProcessus;
LatexHighlighter *highlighter;
QPointer<PdfViewer> pdfviewerWindow;
QPointer<QProgressDialog> progressDialog;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();
void ActualiserLignes(int num);
void ActualiserColonnes(int num);
void ColorerTableau();


QString GenererCode();
void AfficherCode();
void NettoyerCode();

void NouveauTableau();
void SauverTableau();
void ChargerTableau();

void PdfLatexTemp();
void finPdfLatexProcess(int err);
void VoirTemp();

void Aide();

void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
signals:
void pdflatexfini();
};


#endif

==> pdfadd_2.0.1.orig.tar.gz: pdfadd-2.0.1/tabvardialog.h <==
/***************************************************************************
 *   copyright       : (C) 2012-2021 by Pascal Brachet                     *
 *   https://www.xm1math.net/pdfadd/                                       *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 *   @license GPL-2.0+ <https://spdx.org/licenses/GPL-2.0+.html>           *
 ***************************************************************************/

#ifndef TABVARDIALOG_H
#define TABVARDIALOG_H

#include "ui_tabvardialog.h"
#include "latexhighlighter.h"
#include "pdfviewer.h"
#include "cmdlauncher.h"

#include <QProcess>
#include <QPointer>
#include <QCloseEvent>
#include <QProgressDialog>

class TabvarDialog : public QDialog  {
   Q_OBJECT
public:
	TabvarDialog(QWidget *parent=0);
	~TabvarDialog();
	Ui::TabvarDialog ui;
QString extraPath, pdflatexCommande, asyCommande, lecteurpdfCommande, dernierRepertoire, nomFichier;
private :
QString tempDir,texTempFile,pdfTempFile,prefixFile;
QPointer<CmdLauncher> pdflatexproc;
bool estModifie, erreurProcessus;
LatexHighlighter *highlighter;
QPointer<PdfViewer> pdfviewerWindow;
public slots:
void Ouvrir(QString nouveauFichier);
private slots:
void closeEvent(QCloseEvent *e);
void accept();
void reject();
void Init();
void ActualiserLignes(int num);
void ActualiserColonnes(int num);
void ColorerTableau();


QString GenererCode();
void AfficherCode();
void NettoyerCode();

void NouveauTableau();
void SauverTableau();
void ChargerTableau();

void PdfLatexTemp();
void VoirTemp();
void ErreurCompilation();

void Aide();

void ExporterPdf();
void ExporterPdfSuite();
void CopierFichier(QString origine,QString destination);
signals:
void pdflatexfini();
};


#endif
